Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(289)

Unified Diff: pkg/analysis_server/test/analysis_abstract.dart

Issue 875163002: Make AnalysisServer.onAnalysisComplete a Future and wait for it before refactoring. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Use Completer instead of busy loop Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/test/analysis_abstract.dart
diff --git a/pkg/analysis_server/test/analysis_abstract.dart b/pkg/analysis_server/test/analysis_abstract.dart
index 3cf7602ea3050996712579d6ecb773a156dd990e..b167e77e06eeb1b2ef61f8bc141bfe063a12d77e 100644
--- a/pkg/analysis_server/test/analysis_abstract.dart
+++ b/pkg/analysis_server/test/analysis_abstract.dart
@@ -258,10 +258,9 @@ class AbstractAnalysisTest {
}
/**
* Returns a [Future] that completes when the [AnalysisServer] finishes
* all its scheduled tasks.
*/
Future waitForTasksFinished() {
- return waitForServerOperationsPerformed(server);
+ return server.onAnalysisComplete;
}
}
@@ -258,10 +258,9 @@ class AbstractAnalysisTest {
}
/**
- * Returns a [Future] that completes when the [AnalysisServer] finishes
- * all its scheduled tasks.
+ * Returns a [Future] that completes when the server's analysis is complete.
*/
Future waitForTasksFinished() {

Powered by Google App Engine
This is Rietveld 408576698